/**
   Experiment: Controlling A Stepper Motor With Your Muscles
   Link: https://backyardbrains.com/experiments/MuscleSpikerShield_StepperMotor
   Created by Jose Lopez
   Edited by: Miguel Cornejo
   Date edit: March 4th, 2021
**/
#include <AccelStepper.h> //Include AccelStepper library, via Arduino or Internet

#define DIR 7                   //DIR pin from A4988 to pin 7
#define STEP 4                  //STEP pin from A4988 to pin 4
#define MOTOR_INTERFACE_TYPE 1  //How many motors are connected (Maximum motors are 4)

AccelStepper stepper = AccelStepper(MOTOR_INTERFACE_TYPE, STEP, DIR); //Create a new instance of the AccelStepper class

#define MAX 60                  // Maximum reading possible. PLAY WITH THIS VALUE!
#define MAX_STEPS 10            // This is the maximum number of steps that will advance (You can modify this value).
int readings[10];               // Array of readings.
int finalReading;               // Averaged out reading from readings array.
byte multiplier = 1;            // Multiplier for analog readings.
byte numSteps = 0;              // The number of steps to take.
int currentSteps = 0;           // The current number of steps taken.
void setup() {
  Serial.begin(9600);         //begin serial communications
  stepper.setMaxSpeed(500);    //Set the maximum speed in steps per second
}

void loop() {
  for (int i = 0; i < 10; i++) {                              //Takes ten readings in ~ 0.02 seconds.
    readings[i] = analogRead(A0) * multiplier;
    delay(2);

  }
  for (int i = 0; i < 10; i++) {                              //Average the 10 readings.
    finalReading += readings[i];
  }
  finalReading /= 10;

  finalReading = constrain(finalReading, 0, MAX);            //Restrict "readEnd" to a defined range (0-> MAX).
  numSteps = map(finalReading, 0, MAX, 0, MAX_STEPS);        //Convert the value of "readfinal" to a number of steps to advance.

  if (numSteps >= 10)                                         //If there is no reading, the engine stops.
  {
    stepper.setSpeed(1000);       //Set the speed in steps per second (If you want it to go from one side or the other, put the positive or negative number)
    stepper.runSpeed();          //Accelerate the motor with a constant speed set by setSpeed()

  }

  else {
    for (currentSteps = 0 ; currentSteps <= numSteps ; currentSteps++)
    {
      Serial.print("Current Steps:");
      Serial.print(currentSteps);
      Serial.print("   ");
      Serial.print("Final Reading:");
      Serial.print(finalReading);
      Serial.print("   ");
      Serial.print("Steps Advanced:");
      Serial.println(numSteps);
      stepper.stop();
      delay(50);
    }
  }
  delay(10);
}
